#
# spec file for package mdevctl
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mdevctl
Version:        1.2.0
Release:        1.3
Summary:        Mediated device management and persistence utility
License:        LGPL-2.1-or-later
URL:            https://github.com/mdevctl/mdevctl
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo
BuildRequires:  python3-docutils
BuildRequires:  rust
BuildRequires:  zstd
BuildRequires:  pkgconfig(udev)

%description
mdevctl is a utility for managing and persisting devices in the mediated device
framework of the Linux kernel. Mediated devices are sub-devices of a parent
device (e.g. a vGPU) which can be dynamically created and potentially used by
drivers like vfio-mdev for assignment to virtual machines.

%prep
%autosetup -p1
%setup -q -D -T -a 1
mkdir -p cargo-home
cat >cargo-home/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
export CARGO_HOME=$PWD/cargo-home
cargo build --release %{?_smp_mflags}

%install
%make_install

%check
export MDEVCTL_LOG=debug RUST_BACKTRACE=full
export CARGO_HOME=$PWD/cargo-home
cargo test

%files
%license COPYING
%doc README.md
%{_sbindir}/mdevctl
%{_sbindir}/lsmdev
%{_udevrulesdir}/60-mdevctl.rules
%dir %{_sysconfdir}/mdevctl.d
%dir %{_sysconfdir}/mdevctl.d/scripts.d
%dir %{_sysconfdir}/mdevctl.d/scripts.d/callouts
%dir %{_sysconfdir}/mdevctl.d/scripts.d/notifiers
%{_mandir}/man8/mdevctl.8%{?ext_man}
%{_mandir}/man8/lsmdev.8%{?ext_man}
%{_datadir}/bash-completion/completions/mdevctl
%{_datadir}/bash-completion/completions/lsmdev

%changelog
* Sun Dec 11 2022 dmueller@suse.com
- Update to version 1.2.0:
  * Port CLI to clap v3
  * start: provide useful hint for parent with wrong case
  * tests: Add ability to test error messages
  * tests: extract function for checking pass/fail expectations
  * MDev::create() does not need to be public
  * Fix new clippy warning
* Mon Mar 14 2022 James Fehlig <jfehlig@suse.com>
- spec: BuildRequires python3-docutils instead of all python
  flavors of the docutils module
* Fri Mar 11 2022 James Fehlig <jfehlig@suse.com>
- spec: Add /etc/mdevctl.d/scripts.d directory to %%files
* Thu Mar 10 2022 ptesarik@suse.com
- Update to version v1.1.0 (jsc#SLE-18449):
  * use imported std::env for CARGO_PKG_VERSION in build.rs directly
  * fix build.rs to allow specify exact path or name of the rst2man
  * Don't call unnecessary to_string()
  * Report a useful error when /etc/mdevctl.d doesn't exist
  * Handle FS permissions problems for defined devices
  * Fix needless borrow warning from clippy
  * tests: read stdin in callout test scripts
  * Report root error when a callout can't be executed
  * Don't emit warning for files in /etc/mdevctl.d/scripts.d
  * env: add function to get base scripts directory
* Thu Jul  8 2021 jfehlig@suse.com
- Update to version 0.81:
  * Automatic version commit for tag 0.81
  * Fix define from jsonfile
* Tue Dec  8 2020 jfehlig@suse.com
- Update to version 0.78:
  * Automatic version commit for tag 0.78
  * use standard bash path
  * avoid other tags spilling into the .spec changelog
  * mdevctl: fix cleanup on error when creating and removing mdev
  * version support
  * Fix attributes getting applied via start-parent-mdevs
  * mdevctl: fix cleanup on error when writing to attribute
  * Remove never used 'available' option
  * Fix attribute validation
  jsc#SLE-15861, bsc#1179770
* Wed Jul  1 2020 James Fehlig <jfehlig@suse.com>
- Initial packaging of mdevctl utility
